# Authors:
#   Jason Gerard DeRose <jderose@redhat.com>
#
# wehjit: A Python web-widget library
# Copyright (C) 2009  Red Hat
#
# This file is part of `wehjit`.
#
# `wehjit` is free software: you can redistribute it and/or modify it under the
# terms of the GNU General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any later
# version.
#
# `wehjit` is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
# A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# `wehjit`.  If not, see <http://www.gnu.org/licenses/>.

"""
AJAX Grid.
"""

from wehjit.util import dumps


cols = 5
rows = 25

def cell(r, c):
    if c % 2 == 0:
        return '%03d-%d' % (r, c)
    return '%d-%d' % (r % 10, c)

def colname(c):
    return 'col%d' % c


def col(c):
    return dict(
        name=colname(c),
        label='Column %d' % c,
        css_classes='numeric',
    )

def get_rows():
    return [
        dict(
            uid='flast%02d' % i,
            givenname='First%02d' % i,
            sn='Last%02d' % i,
        )
        for i in xrange(rows)
    ]


def create_page(app):
    page = app.new('PageGrid')
    page.grid.cols = [
        dict(
            name='uid',
            label='Login',
            css_classes=None,
        ),
        dict(
            name='givenname',
            label='First Name',
            css_classes=None,
        ),
        dict(
            name='sn',
            label='Last Name',
            css_classes=None,
        ),
        dict(
            name='loginshell',
            label='Shell',
            css_classes=None,
        ),
    ]
    page.cruds.jsonrpc_url = '/jsonrpc'
    page.cruds.autoload = True
    page.cruds.key = 'uid'

    page.create.title = 'Create new user'
    page.retrieve.title = 'Showing user "{value}"'
    page.update.title = 'Updating user "{value}"'
    page.delete.title = 'Delete user "{value}"?'


    shells = ('/bin/bash', '/bin/dash', '/bin/sh')
    shell_options = tuple((s, s) for s in shells)

    for ft in (page.create.fieldtable, page.update.fieldtable):
        ft.new_child('TextRow',
            name='givenname', label='First Name', required=True
        )
        ft.new_child('TextRow', name='sn', label='Last Name', required=True)
        if ft is page.create.fieldtable:
            ft.new_child('TextRow', name='uid', label='User Login', required=True)
        ft.new_child('SelectRow', name='loginshell', label='Shell',
            options=shell_options, value='/bin/sh'
        )

    app.assets.register(
        data=dumps(dict(result=get_rows())),
        key='search.json'
    )
    return page
